#!/usr/bin/env python3

import itertools
import traceback

import fdb
import fdb.tuple

fdb.api_version(520)
db = fdb.open()

dataDir = fdb.directory.create_or_open(db, ('myData',))
LXFSub = dataDir['linuxformat']

months = ['May', 'June', 'July', 'August']
years = ['2011', '2012', '2013', '2014']
issue_combos = itertools.product(months, years)
issue_names = [' '.join(tup) for tup in issue_combos]

@fdb.transactional
def add_issue(tr, c):
    tr[LXFSub.pack((c,))] = fdb.tuple.pack((100,))

@fdb.transactional
def init(tr):
    # del tr[LXFSub.range(())]  # Clear the directory
    for issue_name in issue_names:
        add_issue(tr, issue_name)

@fdb.transactional
def available_issues(tr):
    return [LXFSub.unpack(k)[0] for k, v in tr[LXFSub.range(())]]

if __name__ == "__main__":
    print("Starting...")
    init(db)
    all_issues = available_issues(db)
    print(all_issues)
