package main

import (
	"fmt"
	"github.com/apple/foundationdb/bindings/go/src/fdb"
	"github.com/apple/foundationdb/bindings/go/src/fdb/directory"
	"github.com/apple/foundationdb/bindings/go/src/fdb/subspace"
	"github.com/apple/foundationdb/bindings/go/src/fdb/tuple"
	"strconv"
)

var LXFSub subspace.Subspace
var issues []string

func main() {
	fdb.MustAPIVersion(520)
	db := fdb.MustOpenDefault()

	dataDir, err := directory.CreateOrOpen(db, []string{"myData"}, nil)
	if err != nil {
		fmt.Println(err)
		return
	}

	var LXFSub = dataDir.Sub("linuxformat")
	months := []string{"Jan", "Feb", "Mar", "Apr"}
	years := []string{"2015", "2016", "2017", "2018"}

	var issues = make([]string, len(months)*len(years))
	for i := range months {
		for j := range years {
			issues[i*len(months)+j] = fmt.Sprintf("%s %s", months[i], years[j])
		}
	}

	// Initialize database
	_, err = db.Transact(func(tr fdb.Transaction) (interface{}, error) {
		tr.ClearRange(dataDir)
		for i := range issues {
			tr.Set(LXFSub.Pack(tuple.Tuple{issues[i]}), []byte(strconv.FormatInt(100, 10)))
		}
		return nil, nil
	})

	_, err = db.Transact(func(tr fdb.Transaction) (interface{}, error) {
		ri := tr.GetRange(LXFSub, fdb.RangeOptions{}).Iterator()
		for ri.Advance() {
			kv := ri.MustGet()
			t, err := LXFSub.Unpack(kv.Key)
			if err != nil {
				fmt.Println(err)
				return nil, err
			}
			fmt.Println(t[0].(string))
		}
		return nil, nil
	})

	var anotherSS = dataDir.Sub("doesNotExist")
	fmt.Println("Printing anotherSS")
	_, err = db.Transact(func(tr fdb.Transaction) (interface{}, error) {
		ri := tr.GetRange(anotherSS, fdb.RangeOptions{}).Iterator()
		for ri.Advance() {
			kv := ri.MustGet()
			t, err := anotherSS.Unpack(kv.Key)
			if err != nil {
				fmt.Println(err)
				return nil, err
			}
			fmt.Println(t[0].(string))
		}
		return nil, nil
	})
}
